###############################################################################
#
# Tests for XlsxWriter.
#
# SPDX-License-Identifier: BSD-2-Clause
# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
#

from ..excel_comparison_test import ExcelComparisonTest
from ...workbook import Workbook


class TestCompareXLSXFiles(ExcelComparisonTest):
    """
    Test file created by XlsxWriter against a file created by Excel.

    """

    def setUp(self):
        self.set_filename("protect07.xlsx")

    def test_create_file(self):
        """Test the a simple XlsxWriter file with "read-only recommended"."""

        workbook = Workbook(self.got_filename)

        worksheet = workbook.add_worksheet()

        workbook.read_only_recommended()

        workbook.close()

        self.assertExcelEqual()
